@@ -5,7 +5,7 @@ import pathlib
 class DataPackageServerConstants:
     def __init__(self):
         # http server config
-        self.DATABASE = 'CFreeTAKServerDataPackageDataBase.db'
+        self.DATABASE = 'FreeTAKServerDataPackageDataBase.db'
         self.APIPORT = '8080'
         self.DEFAULTRETURN = 'other'
         self.GET = 'GET'
@@ -15,7 +15,7 @@ class DataPackageServerConstants:
         self.HTTPDEBUG = False
         self.HTTPMETHODS = ['POST', 'GET', 'PUT']
         self.IP = "0.0.0.0"
-        self.versionInfo = 'FreeTAKServer-0.8.75-Beta'
+        self.versionInfo = 'FreeTAKServer-0.8.76-Beta'
         self.NodeID = 'Public-FTS'
         self.VERSIONJSON = '{"version":"2","type":"ServerConfig", "data":{"version": "%s", "api": "2","hostname":"%s"}, "nodeId":"%s"}' % (
             self.versionInfo, "0.0.0.0", self.NodeID)
